parse_usdm_instrument

Function parse_usdm_instrument 

pub fn parse_usdm_instrument(
    symbol: &BinanceFuturesUsdSymbol,
    ts_event: UnixNanos,
    ts_init: UnixNanos,
) -> Result<InstrumentAny>
Parses a USD-M Futures symbol definition into a Nautilus futures instrument.

Errors

Returns an error if:

  • Required filter values are missing (PRICE_FILTER, LOT_SIZE).
  • Price or quantity values cannot be parsed.
  • The contract type is not a supported perpetual or delivery contract.
  • A TRADIFI_PERPETUAL underlying type is missing or unsupported.